<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ko">
<context>
    <name>About</name>
    <message>
        <source>Unknown Compiler</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AbstractPage</name>
    <message>
        <source>Go back</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BanDialog</name>
    <message>
        <source>IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP/Nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>you know why</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please, specify %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>permanent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataManager</name>
    <message>
        <source>Use Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FeedbackDialog</name>
    <message>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We are always happy about suggestions, ideas, or bug reports.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send us feedback!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you found a bug, you can see if it&apos;s already been reported here: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your email address is optional, but necessary if you want us to get back at you.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game scheme will auto-select a weapon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GameUIConfig</name>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWApplication</name>
    <message numerus="yes">
        <source>%1 minutes</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1 hour</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1 hours</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1 day</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1 days</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Scheme &apos;%1&apos; not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1

Please check your installation!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWAskQuitDialog</name>
    <message>
        <source>Do you really want to quit?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 has been removed from your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been added to your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been removed from your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been added to your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stylesheet imported from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter %1 if you want to use the current StyleSheet in future, enter %2 to reset!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StyleSheet discarded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StyleSheet saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save StyleSheet to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has joined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has left (%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Cannot save record to file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No nickname supplied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Someone already uses your nickname %1 on the server.
Please pick another nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1&apos;s Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Nick registered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This nick is registered, and you haven&apos;t specified a password.

If this nick isn&apos;t yours, please register your own nick at www.hedgewars.org

Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your nickname is not registered.
To prevent someone else from using it,
please register it at www.hedgewars.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>

Your password wasn&apos;t saved either.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Empty nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Wrong password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You entered a wrong password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Connection error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You reconnected too fast.
Please wait a few seconds and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This page requires an internet connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The room is protected with password.
Please, enter the password:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation type="unfinished">ko.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mission map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hand-drawn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Randomly generated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random maze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load map drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit map drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maze style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mission:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drawn Maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote host has closed connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server is too old. Disconnecting now.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWPasswordDialog</name>
    <message>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To connect to the server, please log in.

If you don&apos;t have an account on www.hedgewars.org,
just enter your nickname.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWUploadVideoDialog</name>
    <message>
        <source>Upload video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HatButton</name>
    <message>
        <source>Change hat (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HatPrompt</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use selected hat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search for a hat:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyBinder</name>
    <message>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LibavInteraction</name>
    <message>
        <source>Audio: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duration: %1m %2s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video: %1x%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MapModel</name>
    <message>
        <source>No description available.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Clear Accounts Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP/Nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expiration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageDataDownload</name>
    <message>
        <source>Loading, please wait.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This page requires an internet connection.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drawn Maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an action to choose a custom key bind for this team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use my default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset all binds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This hedgehog&apos;s name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Randomize this hedgehog&apos;s name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Play again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>(%1 %2)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageInGame</name>
    <message>
        <source>In game...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageInfo</name>
    <message>
        <source>Open the snapshot folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Downloadable Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play a game on a single computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play a game across a network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read about who is behind the Hedgewars Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leave a feedback here reporting issues, suggesting features or just saying how you like Hedgewars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access the user created content downloadable from our website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage videos recorded from game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit game preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play a game across a local area network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play a game on an official server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play local network game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play official network game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit game preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Edit game preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageNetServer</name>
    <message>
        <source>Click here for details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert your address here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset to default colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Socks5 proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTTP proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System proxy settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an action to change what key controls it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset all binds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frontend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frontend audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miscellaneous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video recording options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Rename dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Admin features</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%1 players online</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Search for a room:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create room</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Join room</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open server administration page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams in each clan take successive turns sharing their turn time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add an indestructible border around the terrain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add an indestructible border along the bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None (Default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrap (World wraps)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bounce (Edges reflect)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sea (Edges connect to sea)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Play a quick game against the computer with random settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play a hotseat game against your friends, or AI teams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Campaign Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Practice your skills in a range of training missions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watch recorded demos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load a previously saved game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageTraining</name>
    <message>
        <source>No description available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a mission!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick the mission or training to play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start fighting</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageVideos</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%1 bytes</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>(in progress...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ban</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Follow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restrict Unregistered Players Join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show games in lobby</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show games in-progress</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save account name and password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video is private</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use game resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visual effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In-game sound effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In-game music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frontend sound effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frontend music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable team tags by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable hedgehog tags by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable health tags by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translucent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable translucent tags by default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>Human</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Side-by-side</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top-Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Cyan grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Net game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stereo rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Get Away Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are videos that are currently being processed.
Exiting now will abort them.
Do you really want to quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please provide either the YouTube account name or the email address associated with the Google Account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account name (or email): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video title: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video description: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tags (comma separated): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Framerate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate (Kbps)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game, while some features might be broken or incomplete!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windowed Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send system information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type the security code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Revision</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is distributed under the %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting will be effective at next restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tip: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displayed tags above hogs and translucent tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>World Edge</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hedgehog %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>anonymous</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Connection to server is lost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while authenticating at google.com:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Login or password is incorrect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while sending metadata to youtube.com:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams - Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete the team &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot delete default scheme &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select a record from the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to start server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All file associations have been set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video upload - Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Netgame - Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select a server from the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Play - Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot rename to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot delete file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room Name - Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room Name - Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes - Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes - Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete the game scheme &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos - Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete the video &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to remove %1 file(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Do you really want to cancel uploading %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open &apos;%1&apos; for writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open &apos;%1&apos; for reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot use the ammo &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons - Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot overwrite default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot delete default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons - Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete the weapon set &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Nick not registered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System Information Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to generate captcha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to download captcha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please fill out all fields. Email is optional.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars - Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not all players are ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to start this game?
Not all players are ready.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No description available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set default options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open videos directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload to YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore default coding parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the video directory in your system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload this video to your Youtube account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the default server port for Hedgewars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invite your friends to your server in just 1 click!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click to copy your unique server URL to your clipboard. Send this link to your friends and they will be able to join you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start private server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RoomNamePrompt</name>
    <message>
        <source>Enter a name for your room.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create room</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>set password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RoomsListModel</name>
    <message>
        <source>In progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hand-drawn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SeedPrompt</name>
    <message>
        <source>The map seed is the basis for all random values generated by the game.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Unable to start server at %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to run engine at %1
Error code: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TeamSelWidget</name>
    <message>
        <source>At least two teams are required to play!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemePrompt</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search for a theme:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use selected theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>attack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>put</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>switch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>chat history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>volume down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>volume up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>change mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>long jump</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>high jump</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mute audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hedgehog info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Movement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miscellaneous</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record video:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgehog movement</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Escape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Equals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>server</name>
    <message>
        <source>Restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not room master</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Corrupted hedgehogs info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>too many teams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>too many hedgehogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There&apos;s already a team with same name in the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>round in progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>REMOVE_TEAM: no such team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not team owner!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Less than two clans!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Illegal room name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room with such name already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname already chosen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Illegal nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Protocol already known</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bad number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname is already in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No checker rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>60 seconds cooldown after kick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>kicked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ping timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>bye</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No such room</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room version incompatible to your hedgewars version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Joining restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Registered users only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are banned in this room</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty config entry</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
